@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -38,7 +38,7 @@ use constant (DATASET_HASH_LIMIT => 3000);
 		# region, and a hash returned with potentially a score for each basepair. 
 		# This may become unwieldy for very large regions, which may be better 
 		# served by separate database queries for each window.
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 print "\n This script will collect binned values across genes to create an average gene\n\n";
 
@@ -392,9 +392,10 @@ sub parallel_execution {
 		splice_data_structure($main_data_ref, $i, $cpu);
 		
 		# re-open database objects to make them clone safe
-		$mdb = open_db_connection($main_database);
+		# pass second true to avoid cached database objects
+		$mdb = open_db_connection($main_database, 1);
 		if ($data_database) {
-			$ddb = open_db_connection($data_database);
+			$ddb = open_db_connection($data_database, 1);
 		}
 		else {
 			$ddb = $mdb;
@@ -1261,7 +1262,8 @@ genomic coordinates for which to collect data. The file should be a
 tab-delimited text file, one row per feature, with columns representing 
 feature identifiers, attributes, coordinates, and/or data values. The 
 first row should be column headers. Bed files are acceptable, as are 
-text files generated with this program.
+text files generated by other B<BioToolBox> scripts. Files may be 
+gzipped compressed.
 
 =item --out <filename>
 
@@ -1269,26 +1271,20 @@ Specify the output file name.
 
 =item --db <name | filename>
 
-Specify the name of a BioPerl database from which to obtain the 
-annotation, chromosomal information, and/or data. Typically a 
-Bio::DB::SeqFeature::Store database schema is used, either from a 
-relational database, SQLite file, or a single GFF3 file to be loaded 
-into memory. Alternatively, a BigWigSet directory, or a single BigWig, 
-BigBed, or Bam file may be specified. 
-
-A database is required for generating new files. When generating a new 
-genome interval file, a bigFile or Bam file listed as a data source 
-will be adopted as the database. 
-
-For input files, the database name may be obtained from the file 
-metadata. A different database may be specified from that listed in 
-the metadata when a different source is desired. 
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+from which gene or feature annotation may be derived. A database is 
+required for generating new data files with features. This option may 
+skipped when using coordinate information from an input file (e.g. BED 
+file), or when using an existing input file with the database indicated 
+in the metadata. For more information about using annotation databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
 
 =item --ddb <name | filename>
 
-Optionally specify the name of an alternate data database from which 
-the data should be collected, separate from the primary annotation 
-database. The same options apply as to the --db option. 
+If the data to be collected is from a second database that is separate 
+from the annotation database, provide the name of the data database here. 
+Typically, a second C<Bio::DB::SeqFeature::Store> or BigWigSet database 
+is provided here. 
 
 =item --feature <type | type:source | alias>,...
 
