@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -17,7 +17,7 @@ use Bio::ToolBox::file_helper qw(
 	load_tim_data_file
 	write_tim_data_file
 );
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 print "\n This script will collect information for a list of features\n\n";
 
@@ -106,7 +106,8 @@ my $id_index   = find_column_index($main_data_ref, '^primary_id');
 ### Establish database connection
 unless ($database) {
 	# define database if it wasn't on the command line
-	$database = $main_data_ref->{'db'};
+	$database = $main_data_ref->{'db'} or 
+		die "No database defined! See help\n";
 }
 my $db = open_db_connection($database);
 
@@ -648,17 +649,20 @@ The command line flags and descriptions:
 
 =item --in <filename>
 
-Specify the file name of a previously generated feature dataset.
-It should be in the tim data format that is generated by this
-program and others, although other tab-delimited text data
-formats may be usable. See the file description in C<Bio::ToolBox::file_helper>.
+Specify an input file containing either a list of database features or 
+genomic coordinates for which to collect data. The file should be a 
+tab-delimited text file, one row per feature, with columns representing 
+feature identifiers, attributes, coordinates, and/or data values. The 
+first row should be column headers. Text files generated by other 
+B<BioToolBox> scripts are acceptable. Files may be gzipped compressed.
 
 =item --db <name>
 
-Specify the name of the BioPerl gff database to use as source. This is required 
-for new feature data files. For pre-existing input data files, this argument 
-is optional, but if given it overrides the database listed in the file; this 
-is useful for collecting data from multiple databases.
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+from which gene or feature annotation may be derived. A database is 
+required for generating new data files with features. For more information 
+about using annotation databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
 
 =item --attrib <attribute>
 
